@@ -75,18 +75,6 @@ public:
         Q_UNUSED(text)
         QMessageBox::warning(parentWidget(), tr("LXQt Power Manager Error"), tr("Hibernate failed."));
     }
-
-
-protected:
-    void resizeEvent(QResizeEvent* event) override
-    {
-        Q_UNUSED(event)
-        const QScreen *primaryScreen = QGuiApplication::primaryScreen();
-        const QRect screen = primaryScreen ? primaryScreen->geometry() : QRect();
-        move((screen.width()  - this->width()) / 2,
-             (screen.height() - this->height()) / 2);
-
-    }
 };
 
 PowerManager::PowerManager(QObject * parent, bool skipWarning)
