@@ -436,9 +436,7 @@ LXQtTheme::LXQtTheme(const LXQtTheme &other):
 /************************************************
 
  ************************************************/
-LXQtTheme::~LXQtTheme()
-{
-}
+LXQtTheme::~LXQtTheme() = default;
 
 
 /************************************************
