@@ -14,12 +14,12 @@
     <message>
         <location filename="../lxqtpowermanager.cpp" line="76"/>
         <source>LXQt Power Manager Error</source>
-        <translation>Грешка в LXQt Power Manager</translation>
+        <translation>Грешка в LXQt Управление на захранването</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="76"/>
         <source>Hibernate failed.</source>
-        <translation>Хибернацията е неуспешна.</translation>
+        <translation>Хибернацията неуспешна.</translation>
     </message>
 </context>
 <context>
@@ -27,7 +27,7 @@
     <message>
         <location filename="../lxqtnotification.cpp" line="163"/>
         <source>Notifications Fallback</source>
-        <translation>Резервни известия</translation>
+        <translation>Предупреждение за известия</translation>
     </message>
 </context>
 <context>
@@ -35,17 +35,17 @@
     <message>
         <location filename="../lxqtpowermanager.cpp" line="108"/>
         <source>Hibernate</source>
-        <translation>Хибернирай</translation>
+        <translation>Хибернация</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="115"/>
         <source>Suspend</source>
-        <translation>Спиране</translation>
+        <translation>Приспиване</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="122"/>
         <source>Reboot</source>
-        <translation>Рестарт</translation>
+        <translation>Рестартиране</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="129"/>
@@ -55,73 +55,73 @@
     <message>
         <location filename="../lxqtpowermanager.cpp" line="136"/>
         <source>Logout</source>
-        <translation>Излизане</translation>
+        <translation>Напускане на сесията</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="148"/>
         <source>LXQt Session Suspend</source>
-        <translation>Прекратяване на LXQt сесия</translation>
+        <translation>Приспиване</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="149"/>
         <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
-        <translation>Искате ли наистина да спрете компютъра си? &lt;p&gt; Спира компютъра в състояние на ниска консумация на енергия. Състоянието на системата не се запазва, ако захранването е изгубено.</translation>
+        <translation>Наистина ли искате да приспите компютъра си? &lt;p&gt; Компютърът преминава в режим на ниско енергийно потребление. Състоянието на системата не се запазва, ако захранването се прекъсне.</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="158"/>
         <source>LXQt Session Hibernate</source>
-        <translation>Хибернация на LXQt сесия</translation>
+        <translation>Хибернация</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="159"/>
         <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
-        <translation>Искате ли наистина да хибернирате компютъра си? &lt;p&gt; Хибернация на компютъра в ниско състояние на енергия. Състоянието на системата се запазва при загуба на мощност.</translation>
+        <translation>Наистина ли искате да спрете компютъра си? &lt;p&gt; Компютърът записва текущата сесия на диска и се изключва. Сесията се възстановява отново при стартиране.</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="168"/>
         <source>LXQt Session Reboot</source>
-        <translation>Рестартиране на LXQt сесия</translation>
+        <translation>Рестартиране</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="169"/>
         <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
-        <translation>Искате ли наистина да рестартирате компютъра си? Всичката не запазена работа ще бъде изгубена...</translation>
+        <translation>Наистина ли искате да рестартирате компютъра си? &lt;p&gt; Всичката незапазена информация се загубва...</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="178"/>
         <source>LXQt Session Shutdown</source>
-        <translation>Изключване на LXQt сесия</translation>
+        <translation>Изключване</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="179"/>
         <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
-        <translation>Искате ли наистина да изключите компютъра си? Всичката не запазена работа ще бъде изгубена...</translation>
+        <translation>Наистина ли искате да изключите компютъра си? &lt;p&gt; Всичката незапазена информация се загубва...</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="188"/>
         <source>LXQt Session Logout</source>
-        <translation>Изход от сесия на LXQt</translation>
+        <translation>Излизане от сесията</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="189"/>
         <source>Do you want to really logout? All unsaved work will be lost...</source>
-        <translation>Искате ли наистина да излезете? Всичката не запазена работа ще бъде изгубена...</translation>
+        <translation>Наистина ли искате да напуснете сесията? &lt;p&gt; Всичката незапазена информация се загубва...</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="197"/>
         <location filename="../lxqtpowermanager.cpp" line="202"/>
         <source>LXQt Power Manager Error</source>
-        <translation>Грешка в LXQt Power Manager</translation>
+        <translation>Грешка в LXQt Управление на захранването</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="197"/>
         <source>Hibernate failed.</source>
-        <translation>Хибернацията е неуспешна.</translation>
+        <translation>Хибернацията неуспешна.</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="202"/>
         <source>Suspend failed.</source>
-        <translation>Спирането не бе успешно.</translation>
+        <translation>Приспиването неуспешно.</translation>
     </message>
 </context>
 <context>
@@ -129,22 +129,22 @@
     <message>
         <location filename="../lxqtscreensaver.cpp" line="160"/>
         <source>Failed to run  &quot;%1&quot;. Ensure you have a locker/screensaver compatible with xdg-screensaver installed and running.</source>
-        <translation>Не можа да се стартира „% 1“. Уверете се, че имате шкафче / скрийнсейвър, съвместимо с xdg-скрийнсейвър, инсталиран и работещ.</translation>
+        <translation>Неуспешно стартиране на „% 1“. Уверете се, че имате инсталиран и работещ скрийнсейвър, съвместим с xdg-screensaver.</translation>
     </message>
     <message>
         <location filename="../lxqtscreensaver.cpp" line="164"/>
         <source>Failed to run  &quot;%1&quot;. Ensure the specified locker/screensaver is installed and running.</source>
-        <translation>Не можа да се стартира „% 1“. Уверете се, че определената шкафче / скрийнсейвър е инсталирана и работи.</translation>
+        <translation>Неуспешно стартиране на „% 1“. Уверете се, че зададеният скрийнсейвър е инсталиран и работещ.</translation>
     </message>
     <message>
         <location filename="../lxqtscreensaver.cpp" line="242"/>
         <source>Lock Screen</source>
-        <translation>Заключващ екран</translation>
+        <translation>Заключване на екрана</translation>
     </message>
     <message>
         <location filename="../lxqtscreensaver.cpp" line="155"/>
         <source>Screen Saver Error</source>
-        <translation>Грешка в скрийвъра</translation>
+        <translation>Грешка на скрийнсейвъра</translation>
     </message>
 </context>
 <context>
@@ -152,7 +152,7 @@
     <message>
         <location filename="../configdialog/lxqtconfigdialogcmdlineoptions.cpp" line="49"/>
         <source>Choose the page to be shown.</source>
-        <translation>Изберете страницата, която да бъде показана.</translation>
+        <translation>Избери страницата за показване.</translation>
     </message>
 </context>
 <context>
@@ -161,7 +161,7 @@
         <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="87"/>
         <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="137"/>
         <source>Power Manager Error</source>
-        <translation>Грешка в Power Manager</translation>
+        <translation>Грешка в управление на захранването</translation>
     </message>
     <message>
         <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="88"/>
@@ -173,7 +173,7 @@
         <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="102"/>
         <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="152"/>
         <source>Power Manager Error (D-BUS call)</source>
-        <translation>Грешка в Power Manager (D-BUS call)</translation>
+        <translation>Грешка в управление на захранването (D-BUS call)</translation>
     </message>
 </context>
 </TS>
